@@ -6,11 +6,18 @@ from core_parser_app.tools.modules.views.module import AbstractModule
 
 
 class AbstractInputModule(AbstractModule, metaclass=ABCMeta):
-    """Input module
-    """
+    """Input module"""
 
-    def __init__(self, scripts=list(), styles=list(), label=None, default_value=None, disabled=False):
-        """ Initialize the module
+    def __init__(
+        self,
+        scripts=list(),
+        styles=list(),
+        label=None,
+        default_value=None,
+        disabled=False,
+        placeholder=None,
+    ):
+        """Initialize the module
 
         Args:
             scripts:
@@ -18,16 +25,18 @@ class AbstractInputModule(AbstractModule, metaclass=ABCMeta):
             label:
             default_value:
             disabled:
+            placeholder:
         """
-        scripts = ['core_parser_app/js/builtin/input.js'] + scripts
+        scripts = ["core_parser_app/js/builtin/input.js"] + scripts
         AbstractModule.__init__(self, scripts=scripts, styles=styles)
 
         self.label = label
         self.default_value = default_value
         self.disabled = disabled
+        self.placeholder = placeholder
 
     def _render_module(self, request):
-        """ Return module's rendering
+        """Return module's rendering
 
         Args:
             request:
@@ -46,4 +55,9 @@ class AbstractInputModule(AbstractModule, metaclass=ABCMeta):
         if self.disabled is not None:
             params.update({"disabled": self.disabled})
 
-        return AbstractModule.render_template('core_parser_app/builtin/input.html', params)
+        if self.placeholder is not None:
+            params.update({"placeholder": self.placeholder})
+
+        return AbstractModule.render_template(
+            "core_parser_app/builtin/input.html", params
+        )
